import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';
import getRootClassName from './utils/getRootClassName';
import { iconShape } from './utils/propTypes';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: iconShape,
            onClick: PropTypes.func,
            target: PropTypes.string,
            to: PropTypes.string,
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                icon: null,
                onClick: (/* evt */) => {},
                target: null,
                to: '',
                ui: ''
            };
        },

        onClick(evt) {
            const { disabled, onClick } = this.props;
            if (disabled) {
                evt.preventDefault();
            }

            onClick(evt);
        },

        render() {
            const { children, disabled, icon, target, to, ui } = this.props;
            return (
                <a
                    className={ getRootClassName(block, { children, icon, ui }, { disabled }) }
                    data-load="static"
                    href={ to }
                    onClick={ this.onClick }
                    target={ target }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </a>
            );
        }

    });

};
